@@ -207,13 +207,12 @@ namespace LinBox
 			return NTL::IsOne (x);
 		}
 
-	bool isMOne (const Element& x) const
+        inline bool isMOne (const Element& x) const
 		{
 			Element y ; neg(y,x);
 			return isOne(y);
 		}
 
-
 		// arithmetic
 
 		/** @brief
@@ -389,7 +388,7 @@ namespace LinBox
 		/** @brief
 		 *  out << y;
 		 */
-		static std::ostream& write(std::ostream& out,const Element& y)  {
+		std::ostream& write(std::ostream& out,const Element& y) const {
 
 			out << y;
 
@@ -413,14 +412,11 @@ namespace LinBox
 		/** @brief
 		 *  Test if x is a unit.
 		 */
-		inline static bool isUnit (const Element& x) {
+		inline bool isUnit(const Element& x) const {
+            NTL::ZZ d;
+            return !NTL::InvModStatus(d,rep(x),NTL::ZZ_p::modulus());
+        }
 
-			NTL::ZZ g;
-
-			NTL::GCD (g, NTL::rep(x), NTL::ZZ_p::modulus());
-
-			return NTL::IsOne (g);
-		}
 
 		/** @brief
 		 *  return g = gcd (a, b)
@@ -643,7 +639,7 @@ namespace LinBox
 	class DotProductDomain;
 
 	template <>
-	class DotProductDomain<PIR_ntl_ZZ_p> : private  VectorDomainBase<PIR_ntl_ZZ_p> {
+	class DotProductDomain<PIR_ntl_ZZ_p> : public  VectorDomainBase<PIR_ntl_ZZ_p> {
 
 	public:
 		typedef PIR_ntl_ZZ_p::Element Element;
@@ -903,11 +899,10 @@ namespace LinBox
 
 #endif //__LINBOX_pir_ntl_zz_p_H
 
-
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
